******************
Getting GooseSLURM
******************

Using conda
===========

The easiest is to use *conda* to install *GooseSLURM*::

    conda install -c conda-forge gooseslurm

This will install all the necessary runtime dependencies as well.

Using PyPi
==========

Equally easy is to use *pip* to install *GooseSLURM*::

    python -m pip install GooseSLURM

This will install all the necessary runtime dependencies as well.

Manual install
==============

Installing GooseSLUM proceeds easily with ``pip``:

.. code-block:: bash

    cd /path/to/GooseSLURM
    python -m pip install . -vv

This should install all the necessary runtime dependencies as well.

.. tip::

    Add the ``--user`` option to the ``pip``-command to install in the user's home-folder.
